"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Utils_1 = __importDefault(require("./Utils"));
const config_1 = __importDefault(require("./config"));
const types_1 = require("./types");
class AuthService {
    proxy;
    routes = {
        session: config_1.default.urls.session,
        login: config_1.default.urls.login,
    };
    constructor(proxy) {
        this.proxy = proxy;
    }
    setSession = (session) => {
        this.proxy.setSession(session);
    };
    getSession = async () => {
        try {
            const ajaxParams = {
                type: types_1.ProxyMethod.GET,
                url: Utils_1.default.getUrl(this.routes.session),
            };
            const response = await this.proxy.ajax(ajaxParams);
            return response.session;
        }
        catch (error) {
            throw error;
        }
    };
    createSession = async (params = {}) => {
        if (config_1.default.creds.appId === '' || config_1.default.creds.authKey === '') {
            throw new Error('Cannot create a new session without "appId" and "authKey"');
        }
        try {
            const ajaxParams = {
                type: types_1.ProxyMethod.POST,
                url: Utils_1.default.getUrl(this.routes.session),
                data: this.generateCreateSessionParams(params),
            };
            const response = await this.proxy.ajax(ajaxParams);
            this.proxy.setSession(response.session);
            this.proxy.setCurrentUserId(response.session.user_id);
            return response.session;
        }
        catch (error) {
            throw error;
        }
    };
    destroySession = async () => {
        try {
            const ajaxParams = {
                type: types_1.ProxyMethod.DELETE,
                url: Utils_1.default.getUrl(this.routes.session),
                dataType: types_1.ProxyType.TEXT,
            };
            await this.proxy.ajax(ajaxParams);
            this.proxy.setSession(null);
            this.proxy.setCurrentUserId(null);
        }
        catch (error) {
            throw error;
        }
    };
    login = async (params) => {
        try {
            const ajaxParams = {
                type: types_1.ProxyMethod.POST,
                url: Utils_1.default.getUrl(this.routes.login),
                data: params,
            };
            const { user } = await this.proxy.ajax(ajaxParams);
            this.proxy.setCurrentUserId(user.id);
            return user;
        }
        catch (error) {
            throw error;
        }
    };
    logout = async () => {
        const ajaxParams = {
            type: types_1.ProxyMethod.DELETE,
            url: Utils_1.default.getUrl(this.routes.login),
            dataType: types_1.ProxyType.TEXT,
        };
        this.proxy.setCurrentUserId(null);
        return this.proxy.ajax(ajaxParams);
    };
    generateCreateSessionParams(params = {}) {
        const message = {
            application_id: config_1.default.creds.appId,
            auth_key: config_1.default.creds.authKey,
        };
        if ('guest' in params) {
            message.user = params;
        }
        else if ('login' in params && 'password' in params) {
            message.user = { login: params.login, password: params.password };
        }
        else if ('email' in params && 'password' in params) {
            message.user = { email: params.email, password: params.password };
        }
        else if ('provider' in params) {
            message.provider = params.provider;
            if ('keys' in params) {
                message.keys = params.keys;
            }
            if ('firebase_phone' in params) {
                message.firebase_phone = params.firebase_phone;
            }
            if ('firebase_email' in params) {
                message.firebase_email = params.firebase_email;
            }
        }
        return message;
    }
}
exports.default = AuthService;
//# sourceMappingURL=Auth.js.map