"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const platform_1 = require("./platform");
const config_1 = __importDefault(require("./config"));
const AddressBook_1 = __importDefault(require("./AddressBook"));
const Auth_1 = __importDefault(require("./Auth"));
const Chat_1 = __importDefault(require("./messaging/Chat"));
const ConferenceClient_1 = __importDefault(require("./videocalling_conference/ConferenceClient"));
const Data_1 = __importDefault(require("./Data"));
const Meetings_1 = __importDefault(require("./Meetings"));
const Proxy_1 = __importDefault(require("./Proxy"));
const PushNotifications_1 = __importDefault(require("./PushNotifications"));
const Storage_1 = __importDefault(require("./Storage"));
const Users_1 = __importDefault(require("./Users"));
const Utils_1 = __importDefault(require("./Utils"));
const WebRTCClient_1 = __importDefault(require("./videocalling/WebRTCClient"));
const Whiteboard_1 = __importDefault(require("./Whiteboard"));
const LinkPreview_1 = __importDefault(require("./LinkPreview"));
class ConnectyCube {
    ConnectyCube;
    utils;
    service;
    auth;
    users;
    storage;
    pushnotifications;
    data;
    addressbook;
    chat;
    meeting;
    whiteboard;
    linkpreview;
    videochat;
    videochatconference;
    setSession;
    getSession;
    createSession;
    destroySession;
    /**
     * @deprecated ConnectyCube.login(user) is deprecated. Use `ConnectyCube.createSession(user)` or `ConnectyCube.auth.login(user)` instead.
     */
    login;
    /**
     * @deprecated ConnectyCube.logout() is deprecated. Use `ConnectyCube.destroySession()` or `ConnectyCube.auth.logout()` instead.
     */
    logout;
    init(credentials, configMap = {}) {
        if (configMap && typeof configMap === 'object') {
            config_1.default.set(configMap);
        }
        this.utils = Utils_1.default;
        this.service = new Proxy_1.default();
        this.auth = new Auth_1.default(this.service);
        this.users = new Users_1.default(this.service);
        this.storage = new Storage_1.default(this.service);
        this.pushnotifications = new PushNotifications_1.default(this.service);
        this.data = new Data_1.default(this.service);
        this.addressbook = new AddressBook_1.default(this.service);
        this.chat = new Chat_1.default(this.service);
        this.meeting = new Meetings_1.default(this.service);
        this.whiteboard = new Whiteboard_1.default(this.service);
        this.linkpreview = new LinkPreview_1.default(this.service);
        if (platform_1.isWebRTCAvailable) {
            this.videochat = new WebRTCClient_1.default(this.chat.xmppClient, this.service);
            this.videochatconference = new ConferenceClient_1.default(this.service);
            this.chat.webrtcSignalingProcessor = this.videochat.signalingProcessor;
        }
        if (credentials.token) {
            config_1.default.creds.appId = credentials.appId;
            this.service.setSession({ token: credentials.token });
        }
        else {
            config_1.default.creds.appId = credentials.appId;
            config_1.default.creds.authKey = credentials.authKey;
        }
        this.setSession = this.auth.setSession;
        this.getSession = this.auth.getSession;
        this.createSession = this.auth.createSession;
        this.destroySession = this.auth.destroySession;
        this.login = this.auth.login;
        this.logout = this.auth.logout;
    }
}
exports.default = ConnectyCube;
//# sourceMappingURL=ConnectyCube.js.map