"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Utils_1 = __importDefault(require("./Utils"));
const config_1 = __importDefault(require("./config"));
const types_1 = require("./types");
class DataService {
    proxy;
    route = config_1.default.urls.data;
    constructor(proxy) {
        this.proxy = proxy;
    }
    async create(className, params = {}) {
        const isMany = Utils_1.default.isArray(params);
        const multi = isMany ? 'multi' : undefined;
        const ajaxParams = {
            type: types_1.ProxyMethod.POST,
            url: Utils_1.default.getUrl(this.route, className, multi),
            data: isMany ? { record: this.createRecord(params) } : params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async list(className, params = {}) {
        const ext = typeof params === 'string' ? params : Utils_1.default.isArray(params) ? params.toString() : undefined;
        const ajaxParams = {
            url: Utils_1.default.getUrl(this.route, className, ext),
            data: ext ? undefined : params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async readPermissions(className, id) {
        const ajaxParams = {
            url: Utils_1.default.getUrl(this.route, className, id),
            data: { permissions: 1 },
        };
        return this.proxy.ajax(ajaxParams);
    }
    async update(className, params = {}) {
        const isMany = Utils_1.default.isArray(params);
        const isSearch = !isMany && params.search_criteria;
        const ext = isMany ? 'multi' : isSearch ? 'by_criteria' : params.id || params._id;
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            url: Utils_1.default.getUrl(this.route, className, ext),
            data: isMany ? { record: this.createRecord(params) } : params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async delete(className, params) {
        const isCriteria = Utils_1.default.isObject(params);
        const isOne = typeof params === 'string' || (Utils_1.default.isArray(params) && params.length === 1);
        const ext = isCriteria ? 'by_criteria' : params.toString();
        const ajaxParams = {
            type: types_1.ProxyMethod.DELETE,
            url: Utils_1.default.getUrl(this.route, className, ext),
            data: isCriteria ? params : undefined,
            dataType: isOne ? types_1.ProxyType.TEXT : undefined,
        };
        return this.proxy.ajax(ajaxParams);
    }
    createRecord(params = []) {
        return params.reduce((items, item, index) => {
            const key = index + 1;
            const id = item.id || item._id;
            const record = id ? { ...item, id } : item;
            return { ...items, [key]: record };
        }, {});
    }
}
exports.default = DataService;
//# sourceMappingURL=Data.js.map