"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = __importDefault(require("./config"));
const types_1 = require("./types");
class LinkPreviewService {
    proxy;
    cache = new Map();
    route = config_1.default.urls.unfurl;
    server = config_1.default.linkpreview.server;
    constructor(proxy) {
        this.proxy = proxy;
    }
    async get(url) {
        if (!this.cache.has(url)) {
            let linkPreview;
            try {
                const ajaxParams = {
                    type: types_1.ProxyMethod.POST,
                    url: `${this.server}/${this.route}`,
                    data: { url },
                };
                linkPreview = (await this.proxy.ajax(ajaxParams));
            }
            catch (error) {
                const title = this.getHostFromUrl(url);
                linkPreview = { url, title, description: '', images: [] };
            }
            finally {
                this.cache.set(url, linkPreview);
            }
        }
        return this.cache.get(url);
    }
    getHostFromUrl(url) {
        if (typeof URL === 'function') {
            return new URL(url).hostname;
        }
        const match = url.match(/^(?:https?:\/\/)?([^\/]+)/);
        return match ? match[1] : url;
    }
}
exports.default = LinkPreviewService;
//# sourceMappingURL=LinkPreview.js.map