"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Utils_1 = __importDefault(require("./Utils"));
const config_1 = __importDefault(require("./config"));
const types_1 = require("./types");
class MeetingsService {
    proxy;
    route = config_1.default.urls.meetings;
    constructor(proxy) {
        this.proxy = proxy;
    }
    async get(params = {}) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async create(params = {}) {
        const MINUTE = 60;
        const startTimestamp = Math.ceil(Date.now() / 1000);
        const endTimestamp = startTimestamp + 60 * MINUTE;
        const defaultName = new Date(startTimestamp).toLocaleString('en', {
            year: 'numeric',
            month: 'long',
            day: 'numeric',
            hour: 'numeric',
            minute: 'numeric',
        });
        const defaultParams = {
            name: defaultName,
            start_date: startTimestamp,
            end_date: endTimestamp,
            attendees: [],
            record: false,
            chat: false,
        };
        const ajaxParams = {
            type: types_1.ProxyMethod.POST,
            url: Utils_1.default.getUrl(this.route),
            data: { ...defaultParams, ...params },
        };
        return this.proxy.ajax(ajaxParams);
    }
    async update(id, params) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            url: Utils_1.default.getUrl(this.route, id),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async delete(id) {
        const ajaxParams = {
            type: types_1.ProxyMethod.DELETE,
            url: Utils_1.default.getUrl(this.route, id),
            dataType: types_1.ProxyType.TEXT,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async getRecordings(id) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route, 'recordings', id),
        };
        return this.proxy.ajax(ajaxParams);
    }
}
exports.default = MeetingsService;
//# sourceMappingURL=Meetings.js.map