"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Utils_1 = __importDefault(require("./Utils"));
const config_1 = __importDefault(require("./config"));
const types_1 = require("./types");
class StorageService {
    proxy;
    route = config_1.default.urls.blobs;
    constructor(proxy) {
        this.proxy = proxy;
    }
    async list(params = {}) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async create(params) {
        const ajaxParams = {
            type: types_1.ProxyMethod.POST,
            url: Utils_1.default.getUrl(this.route),
            data: { blob: params },
        };
        return this.proxy.ajax(ajaxParams);
    }
    async delete(id) {
        const ajaxParams = {
            type: types_1.ProxyMethod.DELETE,
            url: Utils_1.default.getUrl(this.route, id),
            dataType: types_1.ProxyType.TEXT,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async createAndUpload(params) {
        const { name, file, size, abort_id, type: content_type, public: isPublic = true } = params;
        const createParams = { name, content_type, public: isPublic };
        let blob;
        return this.create(createParams)
            .then(({ blob: blobObject }) => {
            blob = blobObject;
            const uri = this.parseUri(blob.blob_object_access?.params);
            const uploadUrl = `${uri.protocol}://${uri.authority}${uri.path}`;
            const uploadParams = { url: uploadUrl, data: {} };
            if (abort_id) {
                uploadParams.abort_id = abort_id;
            }
            Object.keys(uri.queryKey).forEach((key) => {
                uploadParams.data[key] = decodeURIComponent(uri.queryKey[key]);
            });
            uploadParams.data.file = file;
            return this.upload(uploadParams).then(() => blob);
        })
            .then((blob) => this.markUploaded({ id: blob.id, size }).then(() => blob))
            .then((blob) => ({ ...blob, size }));
    }
    async upload(params) {
        const ajaxParams = {
            ...params,
            type: types_1.ProxyMethod.POST,
            dataType: types_1.ProxyType.TEXT,
            contentType: false,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async markUploaded(params) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            url: Utils_1.default.getUrl(this.route, params.id, 'complete'),
            data: {
                size: params.size,
            },
            dataType: types_1.ProxyType.TEXT,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async getInfo(id) {
        const ajaxParams = {
            url: Utils_1.default.getUrl(this.route, id),
        };
        return this.proxy.ajax(ajaxParams);
    }
    async getFile(uid) {
        const ajaxParams = {
            url: Utils_1.default.getUrl(this.route, uid),
        };
        return this.proxy.ajax(ajaxParams);
    }
    async getFileObject(uid, params) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route, uid, 'object'),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async update(params) {
        const data = { blob: {} };
        if (typeof params.name !== 'undefined') {
            data.blob.name = params.name;
        }
        const ajaxParams = {
            url: Utils_1.default.getUrl(this.route, params.id),
            data: data,
        };
        return this.proxy.ajax(ajaxParams);
    }
    privateUrl(fileUID = '') {
        return `https://${config_1.default.endpoints.api}/blobs/${fileUID}?token=${this.proxy.getSession()?.token}`;
    }
    publicUrl(fileUID = '') {
        return `https://${config_1.default.endpoints.api}/blobs/${fileUID}`;
    }
    // parseUri 1.2.2
    // (c) Steven Levithan <stevenlevithan.com>
    // MIT License
    // http://blog.stevenlevithan.com/archives/parseuri
    parseUri(str = '') {
        const options = {
            strictMode: false,
            key: [
                'source',
                'protocol',
                'authority',
                'userInfo',
                'user',
                'password',
                'host',
                'port',
                'relative',
                'path',
                'directory',
                'file',
                'query',
                'anchor',
            ],
            q: {
                name: 'queryKey',
                parser: /(?:^|&)([^&=]*)=?([^&]*)/g,
            },
            parser: {
                strict: /^(?:([^:\/?#]+):)?(?:\/\/((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?))?((((?:[^?#\/]*\/)*)([^?#]*))(?:\?([^#]*))?(?:#(.*))?)/,
                loose: /^(?:(?![^:@]+:[^:@\/]*@)([^:\/?#.]+):)?(?:\/\/)?((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?)(((\/(?:[^?#](?![^?#\/]*\.[^?#\/.]+(?:[?#]|$)))*\/?)?([^?#\/]*))(?:\?([^#]*))?(?:#(.*))?)/,
            },
        };
        const m = options.parser[options.strictMode ? 'strict' : 'loose'].exec(str) ?? {};
        const uri = {};
        let i = 14;
        while (i--) {
            uri[options.key[i]] = m[i] || '';
        }
        uri[options.q.name] = {};
        uri[options.key[12]].replace(options.q.parser, ($0, $1, $2) => {
            if ($1) {
                uri[options.q.name][$1] = $2;
            }
        });
        return uri;
    }
}
exports.default = StorageService;
//# sourceMappingURL=Storage.js.map