"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = __importDefault(require("./config"));
const types_1 = require("./types");
const Utils_1 = __importDefault(require("./Utils"));
class UsersService {
    proxy;
    route = config_1.default.urls.users;
    constructor(proxy) {
        this.proxy = proxy;
    }
    async getV2(params) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route, 'v2'),
            useArrayQuery: true,
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async signup(user, auth_key) {
        const ajaxParams = {
            authKey: auth_key ?? config_1.default.creds.authKey,
            type: types_1.ProxyMethod.POST,
            url: Utils_1.default.getUrl(this.route),
            data: { user },
        };
        return this.proxy.ajax(ajaxParams);
    }
    async update(user = {}) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            url: Utils_1.default.getUrl(this.route, this.proxy.getCurrentUserId()),
            data: { user },
        };
        return this.proxy.ajax(ajaxParams);
    }
    async delete() {
        const ajaxParams = {
            type: types_1.ProxyMethod.DELETE,
            url: Utils_1.default.getUrl(this.route, this.proxy.getCurrentUserId()),
            dataType: types_1.ProxyType.TEXT,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async resetPassword(email = '') {
        const ajaxParams = {
            type: types_1.ProxyMethod.POST,
            url: Utils_1.default.getUrl(this.route, 'password', 'reset'),
            data: { email },
            dataType: types_1.ProxyType.TEXT,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async listOnline(params = {}) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route, 'online'),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async getOnlineCount() {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route, 'online'),
            data: { count: true },
        };
        return this.proxy.ajax(ajaxParams);
    }
    /**
     * @deprecated Use `getV2(params)` instead.
     */
    async get(params) {
        let data = Utils_1.default.cloneObject(params);
        let url = '';
        const filters = [];
        const dateFields = ['created_at', 'updated_at', 'last_request_at'];
        const numberFields = ['id', 'external_user_id'];
        const extensions = {
            login: 'by_login',
            full_name: 'by_full_name',
            facebook_id: 'by_facebook_id',
            twitter_id: 'by_twitter_id',
            phone: 'phone',
            email: 'by_email',
            tags: 'by_tags',
            external: 'external',
        };
        function generateFilter(filter) {
            const obj = Utils_1.default.cloneObject(filter);
            let type = dateFields.includes(obj.field) ? 'date' : typeof obj.value;
            if (Utils_1.default.isArray(obj.value)) {
                if (type === 'object') {
                    type = typeof obj.value[0];
                }
                obj.value = obj.value.toString();
            }
            return [type, obj.field, obj.param, obj.value].join(' ');
        }
        if (data.order) {
            const type = data.order.field in dateFields ? 'date' : data.order.field in numberFields ? 'number' : 'string';
            data.order = [data.order.sort, type, data.order.field].join(' ');
        }
        if (data && data.filter) {
            if (Utils_1.default.isArray(data.filter)) {
                data.filter.forEach((filter) => {
                    filters.push(generateFilter(filter));
                });
            }
            else {
                filters.push(generateFilter(data.filter));
            }
            data.filter = filters;
        }
        if (typeof data === 'number') {
            url = data;
            data = undefined;
        }
        else {
            for (const key in extensions) {
                if (data[key]) {
                    url = extensions[key];
                    if (key === extensions.external) {
                        url += `/${data[extensions.external]}`;
                        data = undefined;
                    }
                    break;
                }
            }
        }
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route, url),
            data,
        };
        return this.proxy.ajax(ajaxParams);
    }
}
exports.default = UsersService;
//# sourceMappingURL=Users.js.map