"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const platform_1 = require("./platform");
const config_1 = __importDefault(require("./config"));
class Utils {
    static loggers = [];
    static env = {
        isReactNative: platform_1.isReactNative,
        isBrowser: platform_1.isBrowser,
        isNodeJS: platform_1.isNodeJS,
        isExpo: platform_1.isExpo,
    };
    static safeCallbackCall(cb = () => { }) {
        return (...args) => {
            if (typeof cb === 'function') {
                try {
                    cb(...args);
                }
                catch (err) {
                    console.error('Error in listener:', err, `Check the code:\n>>>\n${cb.toString()}\n<<<`);
                }
            }
        };
    }
    static getUrl(base, res, ext) {
        const resource = res ? `/${res}` : '';
        const extension = ext ? `/${ext}` : '';
        return `https://${config_1.default.endpoints.api}/${base}${resource}${extension}${config_1.default.urls.type}`;
    }
    static isArray(arg) {
        return Array.isArray(arg);
    }
    static isObject(obj) {
        return Object.prototype.toString.call(obj) === '[object Object]';
    }
    static getBsonObjectId() {
        // The object for type MongoDB.Bson.ObjectId
        // http://docs.mongodb.org/manual/reference/object-id/
        const ObjectId = {
            machine: Math.floor(Math.random() * 16777216).toString(16),
            pid: Math.floor(Math.random() * 32767).toString(16),
            increment: 0,
        };
        const timestamp = Math.floor(Date.now() / 1000).toString(16);
        const increment = (ObjectId.increment++).toString(16);
        if (parseInt(increment, 16) > 0xffffff) {
            ObjectId.increment = 0;
        }
        return (timestamp.padStart(8, '0') +
            ObjectId.machine.padStart(6, '0') +
            ObjectId.pid.padStart(4, '0') +
            increment.padStart(6, '0'));
    }
    static DLog(...args) {
        if (Utils.loggers.length > 0) {
            Utils.loggers.forEach((logger) => logger(args));
            return;
        }
        const consoleLoggerFunction = () => {
            return (args) => {
                console.log(...args);
            };
        };
        if (typeof config_1.default.debug === 'object') {
            const modes = Array.isArray(config_1.default.debug.mode) ? config_1.default.debug.mode : [config_1.default.debug.mode];
            modes.forEach((mode) => {
                if (mode === 1) {
                    Utils.loggers.push(consoleLoggerFunction());
                }
            });
        }
        Utils.loggers.forEach((logger) => logger(args));
    }
    static callTrafficUsageCallback(callbackName, data) {
        if (typeof config_1.default.on[callbackName] === 'function') {
            const getStringSize = (str) => new Blob([str]).size;
            const getDataSize = (data = {}) => {
                const { body: b, headers: h } = data;
                let size = 0;
                if (b) {
                    size += getStringSize(typeof b === 'string' ? b : JSON.stringify(b));
                }
                if (h) {
                    size += getStringSize(JSON.stringify(h));
                }
                return size;
            };
            config_1.default.on[callbackName](getDataSize(data));
        }
    }
    static cloneObject(obj = {}, escapeNull = false) {
        try {
            const json = JSON.stringify(obj);
            const jsonObject = escapeNull ? json.replace(/null/g, '""') : json;
            return JSON.parse(jsonObject);
        }
        catch {
            return obj;
        }
    }
}
exports.default = Utils;
//# sourceMappingURL=Utils.js.map