"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = __importDefault(require("./config"));
const Utils_1 = __importDefault(require("./Utils"));
const types_1 = require("./types");
class WhiteboardService {
    proxy;
    route = config_1.default.urls.whiteboards;
    server = config_1.default.whiteboard.server;
    constructor(proxy) {
        this.proxy = proxy;
    }
    getURL({ id, title, username }) {
        return `${this.server}?whiteboardid=${id}&username=${username}&title=${title}`;
    }
    async get(paramsOrId) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route),
            data: typeof paramsOrId === 'string' ? { chat_dialog_id: paramsOrId } : paramsOrId,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async create(params) {
        const ajaxParams = {
            type: types_1.ProxyMethod.POST,
            url: Utils_1.default.getUrl(this.route),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async update(id, params) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            url: Utils_1.default.getUrl(this.route, id),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async delete(id) {
        const ajaxParams = {
            type: types_1.ProxyMethod.DELETE,
            url: Utils_1.default.getUrl(this.route, id),
            dataType: types_1.ProxyType.TEXT,
        };
        return this.proxy.ajax(ajaxParams);
    }
}
exports.default = WhiteboardService;
//# sourceMappingURL=Whiteboard.js.map