"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Config = void 0;
const platform_1 = require("./platform");
const types_1 = require("./types");
class Config {
    static instance;
    version = platform_1.sdkVersion;
    creds = { appId: '', authKey: '' };
    endpoints = {
        api: 'api.connectycube.com',
        chat: 'chat.connectycube.com',
        muc: 'muc.chat.connectycube.com',
    };
    chatProtocol = {
        bosh: 'https://chat.connectycube.com:5281',
        websocket: 'wss://chat.connectycube.com:5291',
        active: 2,
    };
    chat = {
        streamManagement: { enable: false },
        reconnect: { enable: true, timeInterval: 5 },
    };
    videochat = {
        alwaysRelayCalls: false,
        answerTimeInterval: 60,
        dialingTimeInterval: 5,
        disconnectTimeInterval: 30,
        statsReportTimeInterval: null,
        iceServers: [
            { urls: 'stun:stun.l.google.com:19302' },
            { urls: 'stun:turn.connectycube.com' },
            {
                urls: 'turn:turn.connectycube.com:5349?transport=udp',
                username: 'connectycube',
                credential: '4c29501ca9207b7fb9c4b4b6b04faeb1',
            },
            {
                urls: 'turn:turn.connectycube.com:5349?transport=tcp',
                username: 'connectycube',
                credential: '4c29501ca9207b7fb9c4b4b6b04faeb1',
            },
        ],
    };
    conference = {
        server: 'wss://janus.connectycube.com:8989',
        debug: types_1.JanusDebugMode.ALL,
    };
    whiteboard = { server: 'https://whiteboard.connectycube.com' };
    linkpreview = { server: 'https://linkpreview.connectycube.com' };
    urls = {
        session: 'session',
        login: 'login',
        users: 'users',
        chat: 'chat',
        blobs: 'blobs',
        subscriptions: 'subscriptions',
        events: 'events',
        data: 'data',
        addressbook: 'address_book',
        meetings: 'meetings',
        whiteboards: 'whiteboards',
        unfurl: 'unfurl',
        calls: 'calls',
        type: '.json',
    };
    on = {
        sessionExpired: undefined,
        xmppDataWrite: undefined,
        xmppDataRead: undefined,
    };
    timeout = null;
    debug = { mode: 1 };
    constructor() { }
    static getInstance() {
        if (!Config.instance) {
            Config.instance = new Config();
        }
        return Config.instance;
    }
    set(options) {
        if (options.endpoints && options.endpoints.chat) {
            this.endpoints.muc = `muc.${options.endpoints.chat}`;
            this.chatProtocol.bosh = `https://${options.endpoints.chat}:5281`;
            this.chatProtocol.websocket = `wss://${options.endpoints.chat}:5291`;
        }
        Object.keys(options).forEach((key) => {
            if (key !== 'set' && this.hasOwnProperty(key)) {
                const optionValue = options[key];
                if (typeof optionValue === 'object' && optionValue !== null) {
                    Object.keys(optionValue).forEach((nextKey) => {
                        if (this[key]?.hasOwnProperty(nextKey)) {
                            this[key][nextKey] = optionValue[nextKey];
                        }
                    });
                }
                else {
                    this[key] = optionValue;
                }
            }
        });
    }
}
exports.Config = Config;
exports.default = Config.getInstance();
//# sourceMappingURL=config.js.map