"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Utils_1 = __importDefault(require("../Utils"));
const config_1 = __importDefault(require("../config"));
const types_1 = require("../types");
class DialogsService {
    proxy;
    route = `${config_1.default.urls.chat}/Dialog`;
    constructor(proxy) {
        this.proxy = proxy;
    }
    async list(params = {}) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async create(params) {
        const data = Utils_1.default.cloneObject(params);
        if (Utils_1.default.isArray(data?.occupants_ids)) {
            data.occupants_ids = data.occupants_ids.join(', ');
        }
        if (Utils_1.default.isArray(data?.admins_ids)) {
            data.admins_ids = data.admins_ids.join(', ');
        }
        const ajaxParams = {
            type: types_1.ProxyMethod.POST,
            url: Utils_1.default.getUrl(this.route),
            data: data,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async update(id, params = {}) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            url: Utils_1.default.getUrl(this.route, id),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async delete(idOrIds, params = {}) {
        const idsToDelete = typeof idOrIds === 'string' ? idOrIds.split(',').map((id) => id.trim()) : idOrIds;
        const ajaxParams = {
            type: types_1.ProxyMethod.DELETE,
            url: Utils_1.default.getUrl(this.route, idsToDelete.toString()),
            dataType: idsToDelete.length === 1 ? types_1.ProxyType.TEXT : types_1.ProxyType.JSON,
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async addAdmins(id, admins_ids) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            url: Utils_1.default.getUrl(this.route, id, 'admins'),
            data: { push_all: { admins_ids } },
        };
        return this.proxy.ajax(ajaxParams);
    }
    async removeAdmins(id, admins_ids) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            url: Utils_1.default.getUrl(this.route, id, 'admins'),
            data: { pull_all: { admins_ids } },
        };
        return this.proxy.ajax(ajaxParams);
    }
    async subscribe(id) {
        const ajaxParams = {
            type: types_1.ProxyMethod.POST,
            url: Utils_1.default.getUrl(this.route, id, 'subscribe'),
        };
        return this.proxy.ajax(ajaxParams);
    }
    subscribeToPublic = this.subscribe;
    async unsubscribe(id) {
        const ajaxParams = {
            type: types_1.ProxyMethod.DELETE,
            url: Utils_1.default.getUrl(this.route, id, 'subscribe'),
            dataType: types_1.ProxyType.TEXT,
        };
        return this.proxy.ajax(ajaxParams);
    }
    unsubscribeFromPublic = this.unsubscribe;
    async updateNotificationsSettings(id, enabled) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            url: Utils_1.default.getUrl(this.route, id, 'notifications'),
            data: { enabled: enabled ? 1 : 0 },
        };
        return this.proxy.ajax(ajaxParams);
    }
    async getNotificationsSettings(id) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route, id, 'notifications'),
        };
        return this.proxy.ajax(ajaxParams);
    }
    async getPublicOccupants(id, params = {}) {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            url: Utils_1.default.getUrl(this.route, id, 'occupants'),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async clearHistory(id) {
        const ajaxParams = {
            type: types_1.ProxyMethod.DELETE,
            url: Utils_1.default.getUrl(this.route, 'clearHistory', id),
            dataType: types_1.ProxyType.TEXT,
        };
        return this.proxy.ajax(ajaxParams);
    }
}
exports.default = DialogsService;
//# sourceMappingURL=Dialogs.js.map