"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Utils_1 = __importDefault(require("../Utils"));
const config_1 = __importDefault(require("../config"));
const ChatUtils_1 = __importDefault(require("./ChatUtils"));
class ChatHelpers {
    xmppJID = '';
    get userCurrentJid() {
        return this.xmppJID;
    }
    set userCurrentJid(jid) {
        this.xmppJID = jid || '';
    }
    getUniqueId = ChatUtils_1.default.getUniqueId;
    isNumeric(value) {
        return /^-?\d+$/.test(value) || /^\d+\.\d+$/.test(value);
    }
    jidOrUserId(jidOrUserId) {
        if (typeof jidOrUserId === 'string') {
            return this.isNumeric(jidOrUserId)
                ? this.getUserJid(jidOrUserId)
                : jidOrUserId.includes('@')
                    ? jidOrUserId
                    : this.getRoomJidFromDialogId(jidOrUserId);
        }
        return this.getUserJid(jidOrUserId);
    }
    typeChat(jidOrUserId) {
        switch (typeof jidOrUserId) {
            case 'string':
                return this.isNumeric(jidOrUserId)
                    ? 'chat'
                    : jidOrUserId.includes('@')
                        ? jidOrUserId.includes('muc')
                            ? 'groupchat'
                            : 'chat'
                        : 'groupchat';
            case 'number':
                return 'chat';
            default:
                throw new Error('Unsupported chat type');
        }
    }
    getUserJid(userId) {
        return `${userId}-${config_1.default.creds.appId}@${config_1.default.endpoints.chat}`;
    }
    getUserNickWithMucDomain(userId) {
        return `${config_1.default.endpoints.muc}/${userId}`;
    }
    getUserIdFromJID(jid = this.userCurrentJid) {
        return jid?.includes('@') ? parseInt(jid.split('@')[0].split('-')[0]) : null;
    }
    getDialogIdFromJID(jid) {
        return jid?.includes('@') ? jid.split('@')[0].split('_')[1] : null;
    }
    getRoomJidFromDialogId(dialogId) {
        return `${config_1.default.creds.appId}_${dialogId}@${config_1.default.endpoints.muc}`;
    }
    getRoomJid(jid) {
        return `${jid}/${this.getUserIdFromJID(this.userCurrentJid)}`;
    }
    getIdFromResource(jid) {
        const parts = jid.split('/');
        return parts.length > 1 ? parseInt(parts.slice(1).join('/')) : null;
    }
    getRoomJidFromRoomFullJid(jid) {
        const parts = jid.split('/');
        return parts.length > 1 ? parts[0] : null;
    }
    getBsonObjectId = Utils_1.default.getBsonObjectId;
    getUserIdFromRoomJid(roomJid) {
        const parts = roomJid.split('/');
        return parts.length > 1 ? parseInt(parts[parts.length - 1]) : null;
    }
    getDialogJid(identifier) {
        return identifier.indexOf('@') > 0 ? identifier : this.getRoomJidFromDialogId(identifier);
    }
}
exports.default = ChatHelpers;
//# sourceMappingURL=Helpers.js.map