"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Utils_1 = __importDefault(require("../Utils"));
const config_1 = __importDefault(require("../config"));
const types_1 = require("../types");
class MessagesService {
    proxy;
    route = `${config_1.default.urls.chat}/Message`;
    constructor(proxy) {
        this.proxy = proxy;
    }
    async list(params = {}) {
        const ajaxParams = {
            url: Utils_1.default.getUrl(this.route),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async create(params = {}) {
        const ajaxParams = {
            url: Utils_1.default.getUrl(this.route),
            type: types_1.ProxyMethod.POST,
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async update(id, params = {}) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            dataType: types_1.ProxyType.TEXT,
            url: Utils_1.default.getUrl(this.route, id),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async delete(id, params) {
        const ajaxParams = {
            url: Utils_1.default.getUrl(this.route, id),
            type: types_1.ProxyMethod.DELETE,
            dataType: types_1.ProxyType.TEXT,
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async createSystem(params) {
        const ajaxParams = {
            type: types_1.ProxyMethod.POST,
            url: Utils_1.default.getUrl(this.route, 'system'),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async unreadCount(params = {}) {
        const data = Utils_1.default.cloneObject(params);
        if (data && data.chat_dialog_ids && Utils_1.default.isArray(data.chat_dialog_ids)) {
            data.chat_dialog_ids = data.chat_dialog_ids.join(', ');
        }
        const ajaxParams = {
            url: Utils_1.default.getUrl(this.route, 'unread'),
            data: data,
        };
        return this.proxy.ajax(ajaxParams);
    }
    async listReactions(id = '_') {
        const ajaxParams = {
            type: types_1.ProxyMethod.GET,
            dataType: types_1.ProxyType.JSON,
            url: Utils_1.default.getUrl(this.route, id, 'reactions'),
        };
        return this.proxy.ajax(ajaxParams);
    }
    async addReaction(id, reaction) {
        return this.updateReaction(id, reaction);
    }
    async removeReaction(id, reaction) {
        return this.updateReaction(id, undefined, reaction);
    }
    async updateReaction(id, add, remove) {
        return this.putReaction(id, { add, remove });
    }
    async putReaction(id, params) {
        const ajaxParams = {
            type: types_1.ProxyMethod.PUT,
            dataType: types_1.ProxyType.TEXT,
            url: Utils_1.default.getUrl(this.route, id, 'reactions'),
            data: params,
        };
        return this.proxy.ajax(ajaxParams);
    }
}
exports.default = MessagesService;
//# sourceMappingURL=Messages.js.map