"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ChatUtils_1 = __importDefault(require("./ChatUtils"));
class MultiUserChat {
    xmlns = 'http://jabber.org/protocol/muc';
    helpers;
    xmppClient;
    stanzasCallbacks;
    joinedRooms = {};
    constructor(options) {
        this.helpers = options.helpers;
        this.xmppClient = options.xmppClient;
        this.stanzasCallbacks = options.stanzasCallbacks;
    }
    async join(dialogIdOrJid) {
        return new Promise((resolve, reject) => {
            const id = ChatUtils_1.default.getUniqueId('join');
            const dialogJid = this.helpers.getDialogJid(dialogIdOrJid);
            const presenceStanza = ChatUtils_1.default.createPresenceStanza({
                id: id,
                from: this.helpers.userCurrentJid,
                to: this.helpers.getRoomJid(dialogJid),
            });
            presenceStanza.c('x', { xmlns: this.xmlns }).c('history', { maxstanzas: 0 });
            this.stanzasCallbacks[id] = (stanza) => {
                const x = ChatUtils_1.default.getElement(stanza, 'x');
                const status = ChatUtils_1.default.getElement(x, 'status');
                const code = ChatUtils_1.default.getAttr(status, 'code');
                if (status && code == '110') {
                    this.joinedRooms[dialogJid] = true;
                    resolve();
                }
                else {
                    const isJoin = ChatUtils_1.default.getAttr(x, 'xmlns') === this.xmlns && id.endsWith(':join');
                    const isError = ChatUtils_1.default.getAttr(stanza, 'type') === 'error';
                    if (isJoin && isError) {
                        const errorElement = ChatUtils_1.default.getElement(stanza, 'error');
                        const errorResponse = {
                            code: ChatUtils_1.default.getAttr(errorElement, 'code'),
                            message: ChatUtils_1.default.getElementText(errorElement, 'text') || 'Unknown issue',
                        };
                        reject(errorResponse);
                    }
                }
            };
            this.xmppClient.sendOnline(presenceStanza);
        });
    }
    async leave(dialogIdOrJid) {
        return new Promise((resolve, reject) => {
            const dialogJid = this.helpers.getDialogJid(dialogIdOrJid);
            const presenceStanza = ChatUtils_1.default.createPresenceStanza({
                type: 'unavailable',
                from: this.helpers.userCurrentJid,
                to: this.helpers.getRoomJid(dialogJid),
            });
            delete this.joinedRooms[dialogJid];
            this.stanzasCallbacks['muc:leave'] = (_stanza) => {
                resolve();
            };
            this.xmppClient.sendOnline(presenceStanza);
        });
    }
    async listOnlineUsers(dialogIdOrJid) {
        return new Promise((resolve, _reject) => {
            const id = ChatUtils_1.default.getUniqueId('muc_disco_items');
            const iqStanza = ChatUtils_1.default.createIqStanza({
                type: 'get',
                to: this.helpers.getDialogJid(dialogIdOrJid),
                from: this.helpers.userCurrentJid,
                id,
            });
            iqStanza.c('query', { xmlns: 'http://jabber.org/protocol/disco#items' });
            this.stanzasCallbacks[id] = (stanza) => {
                const stanzaId = ChatUtils_1.default.getAttr(stanza, 'id');
                if (this.stanzasCallbacks[stanzaId]) {
                    const query = ChatUtils_1.default.getAttr(stanza, 'query');
                    const users = ChatUtils_1.default.getChildElements(query)
                        .map((item) => {
                        const roomJid = ChatUtils_1.default.getAttr(item, 'jid');
                        return this.helpers.getUserIdFromRoomJid(roomJid);
                    })
                        .filter((userId) => userId !== null);
                    resolve(users);
                }
            };
            this.xmppClient.sendOnline(iqStanza);
        });
    }
}
exports.default = MultiUserChat;
//# sourceMappingURL=MultiUserChat.js.map