"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.xml = exports.jid = void 0;
exports.xmppClient = xmppClient;
const client_core_1 = require("@xmpp/client-core");
const reconnect_1 = __importDefault(require("@xmpp/reconnect"));
const websocket_1 = __importDefault(require("@xmpp/websocket"));
const middleware_1 = __importDefault(require("@xmpp/middleware"));
const stream_features_1 = __importDefault(require("@xmpp/stream-features"));
const caller_1 = __importDefault(require("@xmpp/iq/caller"));
const callee_1 = __importDefault(require("@xmpp/iq/callee"));
const resolve_1 = __importDefault(require("@xmpp/resolve"));
const sasl_1 = __importDefault(require("@xmpp/sasl"));
const resource_binding_1 = __importDefault(require("@xmpp/resource-binding"));
const session_establishment_1 = __importDefault(require("@xmpp/session-establishment"));
const sasl_anonymous_1 = __importDefault(require("@xmpp/sasl-anonymous"));
const sasl_plain_1 = __importDefault(require("@xmpp/sasl-plain"));
const Utils_1 = __importDefault(require("../Utils"));
function xmppClient(options) {
    const { resource, credentials, username, password, ...params } = options;
    const { domain, service } = params;
    if (!domain && service) {
        params.domain = (service.split('://')[1] || service).split(':')[0].split('/')[0];
    }
    const entity = new client_core_1.Client(params);
    const reconnect = (0, reconnect_1.default)({ entity });
    const websocket = (0, websocket_1.default)({ entity });
    const middleware = (0, middleware_1.default)({ entity });
    const streamFeatures = (0, stream_features_1.default)({ middleware });
    const iqCaller = (0, caller_1.default)({ middleware, entity });
    const iqCallee = (0, callee_1.default)({ middleware, entity });
    const starttls = (0, middleware_1.default)({ entity });
    const resolve = (0, resolve_1.default)({ entity });
    const sasl = (0, sasl_1.default)({ streamFeatures }, credentials || { username, password });
    const resourceBinding = (0, resource_binding_1.default)({ iqCaller, streamFeatures }, resource);
    const sessionEstablishment = (0, session_establishment_1.default)({ iqCaller, streamFeatures });
    const mechanisms = Object.entries({ plain: sasl_plain_1.default, anonymous: sasl_anonymous_1.default }).map(([k, v]) => ({
        [k]: v(sasl),
    }));
    const sendOnline = function (element, ...args) {
        if (entity.status === 'online') {
            return entity.send.call(entity, element, ...args);
        }
        else {
            const message = "You are not connected to chat. Please call 'connect' function first";
            Utils_1.default.DLog('[Chat][Error]', message);
            return Promise.reject(new Error(message));
        }
    };
    return Object.assign(entity, {
        entity,
        reconnect,
        websocket,
        middleware,
        streamFeatures,
        iqCaller,
        iqCallee,
        starttls,
        resolve,
        sasl,
        resourceBinding,
        sessionEstablishment,
        mechanisms,
        sendOnline,
    });
}
exports.jid = client_core_1.jid;
exports.xml = client_core_1.xml;
//# sourceMappingURL=xmpp.js.map