"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = __importDefault(require("../config"));
const platform_1 = require("../platform");
class WebRTCHelpers {
    static getUserJid(id) {
        return `${id}-${config_1.default.creds.appId}@${config_1.default.endpoints.chat}`;
    }
    static getUserIdFromJID(jid) {
        return jid?.includes('@') ? parseInt(jid.split('@')[0].split('-')[0]) : null;
    }
    static trace(text) {
        if (config_1.default.debug) {
            console.log('[VideoChat]:', text);
        }
    }
    static traceWarning(text) {
        if (config_1.default.debug) {
            console.warn('[VideoChat]:', text);
        }
    }
    static traceError(text) {
        if (config_1.default.debug) {
            console.error('[VideoChat]:', text);
        }
    }
    static get getVersionFirefox() {
        const ua = platform_1.navigator?.userAgent ?? null;
        let version = 0;
        if (ua) {
            const ffInfo = ua.match(/(?:firefox)[ \/](\d+)/i) || [];
            version = ffInfo[1] ? +ffInfo[1] : 0;
        }
        return typeof version === 'string' ? parseInt(version) : version;
    }
    static get getVersionSafari() {
        const ua = platform_1.navigator?.userAgent ?? null;
        let version = 0;
        if (ua) {
            const sInfo = ua.match(/(?:safari)[ \/](\d+)/i) || [];
            if (sInfo.length) {
                const sVer = ua.match(/(?:version)[ \/](\d+)/i) || [];
                if (sVer) {
                    version = sVer[1] ? +sVer[1] : 0;
                }
            }
        }
        return typeof version === 'string' ? parseInt(version) : version;
    }
}
exports.default = WebRTCHelpers;
//# sourceMappingURL=WebRTCHelpers.js.map