"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ChatUtils_1 = __importDefault(require("../messaging/ChatUtils"));
const ChatUtils_2 = __importDefault(require("../messaging/ChatUtils"));
const types_1 = require("../types");
class WebRTCSignalingProcessor {
    delegate;
    constructor(delegate) {
        this.delegate = delegate;
    }
    onMessage = (userID, extraParams) => {
        const extension = this.getExtension(extraParams);
        const sessionId = extension?.sessionID ?? '';
        const signalType = extension?.signalType;
        /** cleanup */
        delete extension?.moduleIdentifier;
        delete extension?.sessionID;
        delete extension?.signalType;
        switch (signalType) {
            case types_1.CallSignalingType.CALL:
                this.delegate.onCallHandler(userID, sessionId, extension);
                break;
            case types_1.CallSignalingType.ACCEPT:
                this.delegate.onAcceptHandler(userID, sessionId, extension);
                break;
            case types_1.CallSignalingType.REJECT:
                this.delegate.onRejectHandler(userID, sessionId, extension);
                break;
            case types_1.CallSignalingType.STOP:
                this.delegate.onStopHandler(userID, sessionId, extension);
                break;
            case types_1.CallSignalingType.CANDIDATE:
                this.delegate.onIceCandidatesHandler(userID, sessionId, extension);
                break;
            case types_1.CallSignalingType.RESTART:
                this.delegate.onIceRestartHandler(userID, sessionId, extension);
                break;
            case types_1.CallSignalingType.RESTART_ACCEPT:
                this.delegate.onIceRestartAcceptHandler(userID, sessionId, extension);
                break;
        }
    };
    getExtension(extraParams) {
        if (!extraParams) {
            return {};
        }
        const extension = { iceCandidates: [], opponentsIDs: [] };
        const elements = ChatUtils_2.default.getChildElements(extraParams);
        elements.forEach((element) => {
            const items = ChatUtils_2.default.getChildElements(element);
            const key = ChatUtils_2.default.getName(element) ?? '';
            switch (key) {
                case 'callerID':
                    extension[key] = parseInt(ChatUtils_2.default.getText(element) || '0');
                    break;
                case 'callType':
                    const type = ChatUtils_2.default.getText(element);
                    extension[key] = type === '1' ? types_1.CallType.VIDEO : type === '2' ? types_1.CallType.AUDIO : undefined;
                    break;
                case 'iceCandidates':
                    items.forEach((item) => {
                        const candidate = {};
                        ChatUtils_2.default.getChildElements(item).forEach((child) => {
                            const childName = ChatUtils_2.default.getName(child) || '';
                            const childText = ChatUtils_2.default.getText(child);
                            candidate[childName] = childName === 'sdpMLineIndex' ? parseInt(childText || '0') : childText;
                        });
                        extension.iceCandidates?.push(candidate);
                    });
                    break;
                case 'opponentsIDs':
                    items.forEach((item) => {
                        extension.opponentsIDs?.push(parseInt(ChatUtils_2.default.getText(item) || '0'));
                    });
                    break;
                default:
                    if (items.length > 1) {
                        if ((ChatUtils_2.default.getText(element) || '').length > 4096) {
                            extension[key] = items.reduce((acc, item) => acc + ChatUtils_2.default.getText(item), '');
                        }
                        else {
                            ChatUtils_1.default.assignXmlToObject(element, extension);
                        }
                    }
                    else {
                        if (key === 'userInfo') {
                            ChatUtils_1.default.assignXmlToObject(element, extension);
                        }
                        else {
                            extension[key] = ChatUtils_2.default.getText(element);
                        }
                    }
                    break;
            }
        });
        if (extension.iceCandidates?.length === 0) {
            delete extension.iceCandidates;
        }
        if (extension.opponentsIDs?.length === 0) {
            delete extension.opponentsIDs;
        }
        return extension;
    }
}
exports.default = WebRTCSignalingProcessor;
//# sourceMappingURL=WebRTCSignalingProcessor.js.map