"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Utils_1 = __importDefault(require("../Utils"));
const ChatUtils_1 = __importDefault(require("../messaging/ChatUtils"));
const WebRTCHelpers_1 = __importDefault(require("./WebRTCHelpers"));
const types_1 = require("../types");
class WebRTCSignalingProvider {
    signalingConnection;
    constructor(signalingConnection) {
        this.signalingConnection = signalingConnection;
    }
    sendCandidate(userID, iceCandidates, ext = {}) {
        const extension = Object.assign({}, ext, { iceCandidates });
        this.sendMessage(userID, extension, types_1.CallSignalingType.CANDIDATE);
    }
    sendMessage(userID, ext, signalingType) {
        const extension = Object.assign({}, ext);
        /** basic parameters */
        extension.moduleIdentifier = types_1.CallSignalingModuleIdentifier;
        extension.signalType = signalingType;
        /** extension.sessionID */
        /** extension.callType */
        extension.platform = Utils_1.default.env.isBrowser ? 'web' : Utils_1.default.env.isReactNative || Utils_1.default.env.isExpo ? 'mobile' : 'node';
        /** extension.callerID */
        /** extension.opponentsIDs */
        /** extension.sdp */
        if (extension.userInfo) {
            if (!Object.keys(extension.userInfo).length) {
                delete extension.userInfo;
            }
            else if (extension.userInfo.maxBandwidth === 0) {
                delete extension.userInfo.maxBandwidth;
            }
        }
        let messageStanza = ChatUtils_1.default.createMessageStanza({
            to: WebRTCHelpers_1.default.getUserJid(userID),
            type: 'headline',
            id: Utils_1.default.getBsonObjectId(),
        }).c('extraParams', { xmlns: 'jabber:client' });
        Object.keys(extension).forEach((name) => {
            const item = extension[name];
            if (name === 'iceCandidates') {
                messageStanza = messageStanza.c('iceCandidates');
                item.forEach((candidate) => {
                    messageStanza = messageStanza.c('iceCandidate');
                    Object.keys(candidate).forEach((key) => {
                        messageStanza = messageStanza.c(key).t(candidate[key]).up();
                    });
                    messageStanza = messageStanza.up();
                });
                messageStanza = messageStanza.up();
            }
            else if (name === 'opponentsIDs') {
                messageStanza = messageStanza.c('opponentsIDs');
                item.forEach((opponentId) => {
                    messageStanza = messageStanza.c('opponentID').t(opponentId).up();
                });
                messageStanza = messageStanza.up();
            }
            else if (typeof item === 'object') {
                ChatUtils_1.default.assignObjectToXml(messageStanza, item, name);
            }
            else {
                messageStanza = messageStanza.c(name).t(item).up();
            }
        });
        messageStanza = messageStanza.up();
        this.signalingConnection.sendOnline(messageStanza);
    }
}
exports.default = WebRTCSignalingProvider;
//# sourceMappingURL=WebRTCSignalingProvider.js.map