"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const platform_1 = require("../platform");
const ConferenceSession_1 = __importDefault(require("./ConferenceSession"));
const types_1 = require("../types");
class ConferenceClient {
    proxy;
    DeviceInputType = types_1.DeviceInputType;
    JanusCallType = types_1.JanusCallType;
    sessionsStore = {};
    onParticipantJoinedListener;
    onParticipantLeftListener;
    onSlowLinkListener;
    onRemoteStreamListener;
    onRemoteTracksUpdatedListener;
    onRemoteConnectionStateChangedListener;
    onDataChannelOpenedListener;
    onDataChannelMessageListener;
    onSessionConnectionStateChangedListener;
    onErrorListener;
    constructor(proxy) {
        this.proxy = proxy;
    }
    createNewSession() {
        const session = new ConferenceSession_1.default(this.getCurrentSessionToken());
        this.sessionsStore[session.id] = session;
        session.onParticipantJoinedListener = this.onParticipantJoinedListener;
        session.onParticipantLeftListener = this.onParticipantLeftListener;
        session.onSlowLinkListener = this.onSlowLinkListener;
        session.onRemoteStreamListener = this.onRemoteStreamListener;
        session.onRemoteTracksUpdatedListener = this.onRemoteTracksUpdatedListener;
        session.onRemoteConnectionStateChangedListener = this.onRemoteConnectionStateChangedListener;
        session.onDataChannelOpenedListener = this.onDataChannelOpenedListener;
        session.onDataChannelMessageListener = this.onDataChannelMessageListener;
        session.onSessionConnectionStateChangedListener = this.onSessionConnectionStateChangedListener;
        session.onErrorListener = this.onErrorListener;
        return session;
    }
    async getMediaDevices(kind) {
        if (platform_1.mediaDevices?.enumerateDevices) {
            const devices = await platform_1.mediaDevices.enumerateDevices();
            return kind ? devices.filter((device) => device.kind === kind) : devices;
        }
        else {
            throw new Error("No 'enumerateDevices' API supported");
        }
    }
    clearSession(session_id) {
        delete this.sessionsStore[session_id];
    }
    getCurrentSessionToken() {
        const currentSession = this.proxy.getSession();
        if (currentSession?.token) {
            return currentSession.token;
        }
        else {
            throw new Error('Session does not exist');
        }
    }
    getListenerByName(name) {
        switch (name) {
            case types_1.ConferenceEvent.JOIN:
                return 'onParticipantJoinedListener';
            case types_1.ConferenceEvent.LEFT:
                return 'onParticipantLeftListener';
            case types_1.ConferenceEvent.SLOW_LINK:
                return 'onSlowLinkListener';
            case types_1.ConferenceEvent.REMOTE_STREAM:
                return 'onRemoteStreamListener';
            case types_1.ConferenceEvent.REMOTE_TRACKS_UPDATED:
                return 'onRemoteTracksUpdatedListener';
            case types_1.ConferenceEvent.REMOTE_CONNECTION_STATE:
                return 'onRemoteConnectionStateChangedListener';
            case types_1.ConferenceEvent.DATA_CHANNEL_OPENED:
                return 'onDataChannelOpenedListener';
            case types_1.ConferenceEvent.DATA_CHANNEL_MESSAGE:
                return 'onDataChannelMessageListener';
            case types_1.ConferenceEvent.SESSION_CONNECTION_STATE:
                return 'onSessionConnectionStateChangedListener';
            case types_1.ConferenceEvent.ERROR:
                return 'onErrorListener';
            default:
                return null;
        }
    }
    addListener(name, listener) {
        const listenerName = this.getListenerByName(name);
        if (listenerName) {
            this[listenerName] = listener;
        }
        return this.removeListener.bind(this, name);
    }
    removeListener(name) {
        const listenerName = this.getListenerByName(name);
        if (listenerName) {
            this[listenerName] = undefined;
        }
    }
    removeAllListeners() {
        Object.keys(this).forEach((key) => {
            if (key.startsWith('on') && key.endsWith('Listener') && typeof this[key] === 'function') {
                this[key] = undefined;
            }
        });
    }
}
exports.default = ConferenceClient;
//# sourceMappingURL=ConferenceClient.js.map