export { encode as base64Encode } from 'js-base64';

export const sdkVersion = require('../package.json').version;
export const isBrowser: boolean = false;
export const isNodeJS: boolean = false;
export const isReactNative: boolean = true;
export const isExpo: boolean = typeof global !== 'undefined' && typeof global.Expo !== 'undefined';

export const fetchImpl = fetch;
export const formDataImpl = FormData;

let RNWebRTC: any = {};

try {
  RNWebRTC = require('react-native-webrtc');
} catch {
  console.warn(
    "Module 'react-native-webrtc' is not installed. Please follow the installation guide at https://github.com/react-native-webrtc/react-native-webrtc?tab=readme-ov-file#guides if you want to use WebRTC features."
  );
}

export const {
  mediaDevices,
  MediaStream,
  MediaStreamTrack,
  RTCIceCandidate,
  RTCPeerConnection,
  RTCRtpReceiver,
  RTCRtpSender,
  RTCSessionDescription,
  registerGlobals,
} = RNWebRTC;

export const isWebRTCAvailable: boolean = Boolean(mediaDevices && RTCPeerConnection);

export const navigator = {
  mediaDevices: {
    enumerateDevices: mediaDevices ? mediaDevices.enumerateDevices.bind(mediaDevices) : undefined,
    getUserMedia: mediaDevices ? mediaDevices.getUserMedia.bind(mediaDevices) : undefined,
    getDisplayMedia: mediaDevices ? mediaDevices.getDisplayMedia.bind(mediaDevices) : undefined,
  },
  userAgent: 'react-native',
};

export const adapter = {
  browserDetails: {
    browser: 'react-native',
    version: 0,
  },
};

if (typeof registerGlobals === 'function') {
  try {
    registerGlobals();
  } catch (error) {
    console.warn('[react-native-webrtc] Failed to register globals:', error);
  }
}
